API Reference — artifician Library 0.1 documentation

# API Reference

- artifician package
  - Subpackages
    - artifician.extractors package
      - artifician.extractors.html_extractors module
      - Module contents
    - artifician.processors package
      - artifician.processors.mapper module
      - artifician.processors.normalizer module
      - artifician.processors.processor module
      - Module contents
  - artifician.dataset module
  - artifician.feature_definition module